Index: /pjproject/trunk/pjlib/include/pj/ioqueue.h
===================================================================
--- /pjproject/trunk/pjlib/include/pj/ioqueue.h	(revision 4723)
+++ /pjproject/trunk/pjlib/include/pj/ioqueue.h	(revision 4724)
@@ -643,5 +643,5 @@
  * Instruct the I/O Queue to read from the specified handle. This function
  * returns immediately (i.e. non-blocking) regardless whether some data has 
- * been transfered. If the operation can't complete immediately, caller will 
+ * been transferred. If the operation can't complete immediately, caller will 
  * be notified about the completion when it calls pj_ioqueue_poll(). If data
  * is immediately available, the function will return PJ_SUCCESS and the
@@ -729,7 +729,7 @@
  * Instruct the I/O Queue to write to the handle. This function will return
  * immediately (i.e. non-blocking) regardless whether some data has been 
- * transfered. If the function can't complete immediately, the caller will
+ * transferred. If the function can't complete immediately, the caller will
  * be notified about the completion when it calls pj_ioqueue_poll(). If 
- * operation completes immediately and data has been transfered, the function
+ * operation completes immediately and data has been transferred, the function
  * returns PJ_SUCCESS and the callback will NOT be called.
  *
@@ -753,9 +753,9 @@
  *
  * @return
- *  - PJ_SUCCESS    If data was immediately transfered. In this case, no
+ *  - PJ_SUCCESS    If data was immediately transferred. In this case, no
  *                  pending operation has been scheduled and the callback
  *                  WILL NOT be called.
  *  - PJ_EPENDING   If the operation has been queued. Once data base been
- *                  transfered, the callback will be called.
+ *                  transferred, the callback will be called.
  *  - non-zero      The return value indicates the error code.
  */
@@ -770,7 +770,7 @@
  * Instruct the I/O Queue to write to the handle. This function will return
  * immediately (i.e. non-blocking) regardless whether some data has been 
- * transfered. If the function can't complete immediately, the caller will
+ * transferred. If the function can't complete immediately, the caller will
  * be notified about the completion when it calls pj_ioqueue_poll(). If 
- * operation completes immediately and data has been transfered, the function
+ * operation completes immediately and data has been transferred, the function
  * returns PJ_SUCCESS and the callback will NOT be called.
  *
Index: /pjproject/trunk/pjsip-apps/src/confbot/confbot.py
===================================================================
--- /pjproject/trunk/pjsip-apps/src/confbot/confbot.py	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/confbot/confbot.py	(revision 4724)
@@ -198,5 +198,5 @@
 
 	def on_call_transfer_request(self, call, dst, code):
-		msg = "%(uri)s is transfering the call to %(dst)s" % \
+		msg = "%(uri)s is transferring the call to %(dst)s" % \
 			  {'uri': self.uri, 'dst': dst}
 		self.bot.broadcast_pager(None, msg)
Index: /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app.c
===================================================================
--- /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app.c	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app.c	(revision 4724)
@@ -783,5 +783,5 @@
     if (status_code/100 == 2) {
 	PJ_LOG(3,(THIS_FILE, 
-	          "Call %d: call transfered successfully, disconnecting call",
+	          "Call %d: call transferred successfully, disconnecting call",
 		  call_id));
 	pjsua_call_hangup(call_id, PJSIP_SC_GONE, NULL, NULL);
Index: /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app_cli.c
===================================================================
--- /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app_cli.c	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app_cli.c	(revision 4724)
@@ -1800,5 +1800,5 @@
 	    static pj_str_t err_same_num = 
 				    {"Destination call number must not be the "
-				     "same as the call being transfered\n", 74};
+				     "same as the call being transferred\n", 74};
 
 	    pj_cli_sess_write_msg(cval->sess, err_same_num.ptr, 
Index: /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app_legacy.c
===================================================================
--- /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app_legacy.c	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/pjsua/pjsua_app_legacy.c	(revision 4724)
@@ -1164,5 +1164,5 @@
 	if (dst_call == call) {
 	    puts("Destination call number must not be the same "
-		"as the call being transfered");
+		"as the call being transferred");
 	    return;
 	}
Index: /pjproject/trunk/pjsip-apps/src/py_pjsua/pjsua_app.py
===================================================================
--- /pjproject/trunk/pjsip-apps/src/py_pjsua/pjsua_app.py	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/py_pjsua/pjsua_app.py	(revision 4724)
@@ -158,5 +158,5 @@
 	      
 	if status_code/100 == 2:
-		write_log(3, "Call " + `call_id` + " : call transfered successfully, disconnecting call")
+		write_log(3, "Call " + `call_id` + " : call transferred successfully, disconnecting call")
 		status = py_pjsua.call_hangup(call_id, 410, None, None)
 		p_cont = 0
@@ -424,7 +424,7 @@
 		status = py_pjsua.call_xfer(g_current_call, url, msg_data);
 		if status != 0:
-			py_pjsua.perror(THIS_FILE, "Error transfering call ", status)
+			py_pjsua.perror(THIS_FILE, "Error transferring call ", status)
 		else:		
-			write_log(3, "Call transfered to " + url)
+			write_log(3, "Call transferred to " + url)
 		
 def xfer_call_replaces():
@@ -459,5 +459,5 @@
 		
 		if dst_call == call:
-			print "Destination call number must not be the same as the call being transfered"
+			print "Destination call number must not be the same as the call being transferred"
 			return
 		
Index: /pjproject/trunk/pjsip-apps/src/py_pjsua/py_pjsua.c
===================================================================
--- /pjproject/trunk/pjsip-apps/src/py_pjsua/py_pjsua.c	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/py_pjsua/py_pjsua.c	(revision 4724)
@@ -175,5 +175,5 @@
 
 /*
- * Notify application on call being transfered.
+ * Notify application on call being transferred.
  * !modified @061206
  */
Index: /pjproject/trunk/pjsip-apps/src/python/_pjsua.c
===================================================================
--- /pjproject/trunk/pjsip-apps/src/python/_pjsua.c	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/python/_pjsua.c	(revision 4724)
@@ -209,5 +209,5 @@
 
 /*
- * Notify application on call being transfered.
+ * Notify application on call being transferred.
  * !modified @061206
  */
Index: /pjproject/trunk/pjsip-apps/src/python/_pjsua.h
===================================================================
--- /pjproject/trunk/pjsip-apps/src/python/_pjsua.h	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/python/_pjsua.h	(revision 4724)
@@ -333,5 +333,5 @@
         "on_call_transfer_request", T_OBJECT_EX,
         offsetof(PyObj_pjsua_callback, on_call_transfer_request), 0,
-        "Notify application on call being transfered. "
+        "Notify application on call being transferred. "
 	"Application can decide to accept/reject transfer request "
 	"by setting the code (default is 200). When this callback "
Index: /pjproject/trunk/pjsip-apps/src/python/pjsua.py
===================================================================
--- /pjproject/trunk/pjsip-apps/src/python/pjsua.py	(revision 4723)
+++ /pjproject/trunk/pjsip-apps/src/python/pjsua.py	(revision 4724)
@@ -1387,5 +1387,5 @@
 
     def on_transfer_request(self, dst, code):
-        """Notification that call is being transfered by remote party. 
+        """Notification that call is being transferred by remote party. 
 
         Application can decide to accept/reject transfer request by returning
Index: /pjproject/trunk/pjsip/include/pjsua-lib/pjsua.h
===================================================================
--- /pjproject/trunk/pjsip/include/pjsua-lib/pjsua.h	(revision 4723)
+++ /pjproject/trunk/pjsip/include/pjsua-lib/pjsua.h	(revision 4724)
@@ -757,5 +757,5 @@
 
     /**
-     * Notify application on call being transfered (i.e. REFER is received).
+     * Notify application on call being transferred (i.e. REFER is received).
      * Application can decide to accept/reject transfer request
      * by setting the code (default is 202). When this callback
@@ -766,5 +766,5 @@
      * @param call_id	The call index.
      * @param dst	The destination where the call will be 
-     *			transfered to.
+     *			transferred to.
      * @param code	Status code to be returned for the call transfer
      *			request. On input, it contains status code 200.
@@ -775,5 +775,5 @@
 
     /**
-     * Notify application on call being transfered (i.e. REFER is received).
+     * Notify application on call being transferred (i.e. REFER is received).
      * Application can decide to accept/reject transfer request
      * by setting the code (default is 202). When this callback
@@ -783,9 +783,9 @@
      * @param call_id	The call index.
      * @param dst	The destination where the call will be 
-     *			transfered to.
+     *			transferred to.
      * @param code	Status code to be returned for the call transfer
      *			request. On input, it contains status code 200.
      * @param opt	The current call setting, application can update
-     *			this setting for the call being transfered.
+     *			this setting for the call being transferred.
      */
     void (*on_call_transfer_request2)(pjsua_call_id call_id,
@@ -4652,5 +4652,5 @@
  * of the call transfer request.
  *
- * @param call_id	The call id to be transfered.
+ * @param call_id	The call id to be transferred.
  * @param dest		URI of new target to be contacted. The URI may be
  * 			in name address or addr-spec format.
@@ -4677,5 +4677,5 @@
  * the call with us with the new call from the REFER recipient.
  *
- * @param call_id	The call id to be transfered.
+ * @param call_id	The call id to be transferred.
  * @param dest_call_id	The call id to be replaced.
  * @param options	Application may specify PJSUA_XFER_NO_REQUIRE_REPLACES
Index: /pjproject/trunk/pjsip/include/pjsua2/call.hpp
===================================================================
--- /pjproject/trunk/pjsip/include/pjsua2/call.hpp	(revision 4723)
+++ /pjproject/trunk/pjsip/include/pjsua2/call.hpp	(revision 4724)
@@ -727,5 +727,5 @@
 {
     /**
-     * The destination where the call will be transfered to.
+     * The destination where the call will be transferred to.
      */
     string              dstUri;
@@ -739,5 +739,5 @@
     /**
      * The current call setting, application can update this setting
-     * for the call being transfered.
+     * for the call being transferred.
      */
     CallSetting         opt;
@@ -1530,5 +1530,5 @@
     
     /**
-     * Notify application on call being transfered (i.e. REFER is received).
+     * Notify application on call being transferred (i.e. REFER is received).
      * Application can decide to accept/reject transfer request
      * by setting the code (default is 202). When this callback
Index: /pjproject/trunk/pjsip/src/pjsua-lib/pjsua_call.c
===================================================================
--- /pjproject/trunk/pjsip/src/pjsua-lib/pjsua_call.c	(revision 4723)
+++ /pjproject/trunk/pjsip/src/pjsua-lib/pjsua_call.c	(revision 4724)
@@ -4032,5 +4032,5 @@
 	if (refer_sub && pj_stricmp2(&refer_sub->hvalue, "false")==0) {
 	    /* Since no subscription is desired, assume that call has been
-	     * transfered successfully.
+	     * transferred successfully.
 	     */
 	    if (call && pjsua_var.ua_cfg.cb.on_call_transfer_status) {
@@ -4203,5 +4203,5 @@
  * Follow transfer (REFER) request.
  */
-static void on_call_transfered( pjsip_inv_session *inv,
+static void on_call_transferred( pjsip_inv_session *inv,
 			        pjsip_rx_data *rdata )
 {
@@ -4281,5 +4281,5 @@
     }
 
-    PJ_LOG(3,(THIS_FILE, "Call to %.*s is being transfered to %.*s",
+    PJ_LOG(3,(THIS_FILE, "Call to %.*s is being transferred to %.*s",
 	      (int)inv->dlg->remote.info_str.slen,
 	      inv->dlg->remote.info_str.ptr,
@@ -4487,5 +4487,5 @@
 	 * Incoming REFER request.
 	 */
-	on_call_transfered(call->inv, e->body.tsx_state.src.rdata);
+	on_call_transferred(call->inv, e->body.tsx_state.src.rdata);
 
     }
Index: /pjproject/trunk/tests/pjsua/scripts-sipp/transfer-attended.py
===================================================================
--- /pjproject/trunk/tests/pjsua/scripts-sipp/transfer-attended.py	(revision 4723)
+++ /pjproject/trunk/tests/pjsua/scripts-sipp/transfer-attended.py	(revision 4724)
@@ -42,9 +42,9 @@
 		 [1, "", "X"],
 		 [1, "", "1"],
-		 [0, "Call .* is being transfered", ""],
+		 [0, "Call .* is being transferred", ""],
 		 [1, "Subscription state .* ACCEPTED", ""],
 		 [0, const.STATE_CALLING, ""],
 		 [2, "Call .* is being replaced", ""],
-		 [1, "call transfered successfully", ""],
+		 [1, "call transferred successfully", ""],
 		 [0, const.MEDIA_ACTIVE, ""],
 		 [2, const.MEDIA_ACTIVE, ""],
Index: /pjproject/trunk/tests/pjsua/scripts-sipp/transfer-unattended.py
===================================================================
--- /pjproject/trunk/tests/pjsua/scripts-sipp/transfer-unattended.py	(revision 4723)
+++ /pjproject/trunk/tests/pjsua/scripts-sipp/transfer-unattended.py	(revision 4724)
@@ -26,5 +26,5 @@
 		 [0, const.MEDIA_ACTIVE, ""],
 		 [2, const.MEDIA_ACTIVE, ""],
-		 [1, "call transfered successfully", ""],
+		 [1, "call transferred successfully", ""],
 		 [1, const.STATE_DISCONNECTED, ""]
 		]

Index: /pjproject/trunk/pjlib/src/pj/ioqueue_winnt.c
===================================================================
--- /pjproject/trunk/pjlib/src/pj/ioqueue_winnt.c	(revision 4723)
+++ /pjproject/trunk/pjlib/src/pj/ioqueue_winnt.c	(revision 4724)
@@ -634,10 +634,10 @@
 /*
  * Poll the I/O Completion Port, execute callback, 
  * and return the key and bytes transfered of the last operation.
  */
 static pj_bool_t poll_iocp( HANDLE hIocp, DWORD dwTimeout, 
 			    pj_ssize_t *p_bytes, pj_ioqueue_key_t **p_key )
 {
-    DWORD dwBytesTransfered, dwKey;
+    DWORD dwBytesTransferred, dwKey;
     generic_overlapped *pOv;
     pj_ioqueue_key_t *key;
@@ -646,5 +646,5 @@
 
     /* Poll for completion status. */
-    rcGetQueued = GetQueuedCompletionStatus(hIocp, &dwBytesTransfered,
+    rcGetQueued = GetQueuedCompletionStatus(hIocp, &dwBytesTransferred,
 					    &dwKey, (OVERLAPPED**)&pOv, 
 					    dwTimeout);
@@ -660,5 +660,5 @@
 	/* Event was dequeued for either successfull or failed I/O */
 	key = (pj_ioqueue_key_t*)dwKey;
-	size_status = dwBytesTransfered;
+	size_status = dwBytesTransferred;
 
 	/* Report to caller regardless */
@@ -1382,8 +1382,8 @@
 {
     BOOL rc;
-    DWORD bytesTransfered;
+    DWORD bytesTransferred;
 
     rc = GetOverlappedResult( key->hnd, (LPOVERLAPPED)op_key,
-                              &bytesTransfered, FALSE );
+                              &bytesTransferred, FALSE );
 
     if (rc == FALSE) {
@@ -634,10 +634,10 @@
 /*
  * Poll the I/O Completion Port, execute callback, 
- * and return the key and bytes transfered of the last operation.
+ * and return the key and bytes transferred of the last operation.
  */
 static pj_bool_t poll_iocp( HANDLE hIocp, DWORD dwTimeout, 